# Haveno Exchange, Marketplace & Chat Messaging Protocol Core

<p align="center">
  <a href="https://haveno.com"><img src="https://github.com/KewbitXMR/haveno-app/blob/main/assets/android-chrome-512x512.png?raw=true" width="150" /></a>
  <br/>
  <a href="https://haveno.com"><img src="https://raw.githubusercontent.com/KewbitXMR/haveno-app/refs/heads/main/assets/icon/side1.webp" width="100" /></a>
  <a href="https://haveno.com"><img src="https://raw.githubusercontent.com/KewbitXMR/haveno-app/refs/heads/main/assets/icon/270a7bad400e6824b8ea9f238f66b61a.webp" width="275" /></a>
  <a href="https://haveno.com"><img src="https://raw.githubusercontent.com/KewbitXMR/haveno-app/refs/heads/main/assets/icon/side2.webp" width="100" /></a>
</p>

---

## ⚡ What Is Haveno?

**Haveno** is a free, open-source peer-to-peer exchange platform for Monero (XMR) and other privacy-focused assets. Built on top of Tor for anonymity, it allows users to trade securely without exposing their identity, IP address, or relying on central servers.

We are now entering a **new phase of development** — expanding Haveno’s decentralized trading engine to support a full **decentralized marketplace**, enabling the secure trading of physical and digital items via onion-routed infrastructure.

> Think Monero + eBay, but with no centralized control, and fully private.

---

## 🚀 Project Highlights

- ✅ Full Haveno App for Desktop & Android (macOS, Linux, Windows)
- ✅ gRPC over Tor SOCKS5 tunnel support
- ✅ Encrypted database & AES SharedPreferences
- ✅ Cross-platform Dart SDK
- ✅ Docker deployment support
- ✅ Fluent UI and secure chat
- ✅ **Upcoming: decentralized item trading with multisig escrow**
- ✅ **Upcoming: decentralized chat messaging system, no central servers. Secure, private and simple to use.**

---

## 🧪 Try Haveno Now

**Download the latest pre-release builds:**  
📦 [Releases](https://github.com/KewbitXMR/haveno-app/releases)

Be aware: Current builds are connected to **Stagenet**, a Monero test network.  
Do not send real funds!

📱 [Android Universal APK](https://haveno.com/downloads/)  
💻 [macOS Intel & Silicon](https://haveno.wiki/en/install-guide)  
🐧 [Linux AppImage (Beta)](https://haveno.com/downloads/)  
🐳 [Docker Hub (server-related deployments)](https://hub.docker.com/u/havenodex)

> iOS and Windows Desktop versions are in progress.

---

## 📦 Marketplace Extension (WIP)

We are now actively building:
- 🛒 Item-based listings with escrow logic
- ✅ Full arbitration protocol extensions
- 📤 Decentralized shipment commitment proofs
- 🔐 Encrypted item metadata
- 💬 Integrated chat messaging for item trades
- ⚙️ Fully p2p over Tor with zero server trust

📖 [Marketplace Protocol Spec (Coming Soon)](#)  
📖 [How to list physical goods securely (Coming Soon)](#)  
📖 [Integrating payments with XMR or eGift codes (Coming Soon)](#)

---

## 📚 Helpful Guides

- [Install Haveno on Desktop](https://haveno.com/documentation/installing-haveno-on-desktop/)
- [Install Haveno on Android](https://haveno.com/documentation/install-haveno-on-a-mobile-device/)
- [Setup a Secure Tor Relay with Haveno](https://haveno.com/documentation/tor-setup/)
- [Running Haveno with Docker](https://haveno.com/documentation/installing-the-haveno-daemon-with-docker-securely/)
- [Operating a Custom Haveno Network](https://haveno.com/documentation/setup-a-custom-haveno-network-seednode-with-docker/)
- [Telegram Integration for Notifications](https://haveno.com/documentation/using-telegram-to-manage-your-haveno-account/)

---

## 📡 Network & Federation

The Haveno network is fully decentralized but supports **federated networks** (similar to Matrix or Mastodon). You can either join existing Haveno networks or host your own.

Anyone can contribute from developers, advocates, and sysadmins to:
- Deploy their own network
- Become arbitrators
- Operate price feeds
- Collect trade fees **legally** (we do not condone or support in any way the use of our software fo illict activity in any any juridication where it is not legally permitted.)

📖 [How to Configure a Custom Network (Coming Soon)](#)  
📖 [How Arbitration Works in Haveno (Coming Soon)](#)

---

## 🧩 Roadmap

| Feature | Status |
|--------|--------|
| Protocol Core (v1) | ✅ Complete |
| Dart SDK + Documentation | ✅ Complete |
| Desktop UI (Linux/macOS) | ✅ Stable |
| Android UI | ✅ Stable |
| Marketplace Extension | 🛠 In Progress |
| Rust + Python SDKs | 🛠 In Progress |
| Arbitrator UX + Tools | 🔜 Pending |
| Client Authentication (Onion) | 🔜 Pending |
| Biometric Unlock (Mobile) | 🔜 Planned |
| iOS Support | 🔜 Planned |
| Multi-Currency Atomic Swaps | 🔜 Planned |
| FIDO2 Auth for TX | 🔜 Planned |

---

## 🛠 Contributing

Testing old phones, laptops, and edge devices helps us the most right now.

Want to contribute code, translations, docs, or host a network?

- [Open an Issue](https://github.com/KewbitXMR/haveno-app/issues)
- [Join Our Discussions](https://xmr.social/c/Haveno)
- [Submit Pull Requests](https://github.com/KewbitXMR/haveno-app/pulls)
- [Follow Kewbit on X](https://x.com/kewbit)

---

## ⚠️ Disclaimer

> This software is in testing. The Haveno Protocol Core connects to a Haveno Daemon but does not itself process or hold any financial assets or act as a financial intermediary. You are responsible for complying with local laws regarding privacy-preserving technologies and trade.

---

## ❤️ Thanks

Huge thanks to the Monero community, Haveno contributors, and anyone running seed nodes, [operating haveno networks](https://haveno.com/networks/) or Tor relays to power freedom of trade.

Support and transparency logs can be found on [Kewbit's Privacy Blog](https://kewbit.org).